@@ -13,6 +13,16 @@ from ..config import config
 from ..utils import mjd_to_datetime
 
 
+class _ClientConfigStreamingSchema(Schema):
+    class Meta:
+        type_ = "client_config_streaming"
+        unknown = marshmallow.EXCLUDE
+
+    id = fields.String()
+    type = fields.String()
+    options = fields.Dict()
+
+
 class _AlertSchema(Schema):
     class Meta:
         type_ = "alert"
