@@ -8,37 +8,57 @@ from urllib.parse import urljoin
 import astropy.coordinates
 import astropy.units
 
-from ._api.api import get_resource, list_resource
-from ._api.models import Locus, LocusSchema, LocusListingSchema
+from ._api.api import _get_resource, _list_all_resources
+from ._api.models import Locus, _LocusSchema, _LocusListingSchema
 from .config import config
 
 
 def search(query: Dict) -> Iterator[Locus]:
     """
-    Searches the ANTARES database for loci that meet certain criteria.
+    Searches the ANTARES database for loci that meet certain criteria. Results are
+    returned with the most recently updated objects first (sorted on the
+    `properties.newest_alert_observation_time` field in descending order).
 
     Parameters
     ----------
-    query
+    query: dict
+        An ElasticSearch query. Must contain a top-level "query" key and only that
+        top-level key. Other ES search arguments (e.g. "aggregations") are not allowed.
 
     Returns
-    -------
+    ----------
+    Iterator over Locus objects
 
     """
-    return list_resource(
+    return _list_all_resources(
         urljoin(config["ANTARES_API_BASE_URL"], "loci"),
-        LocusListingSchema,
+        _LocusListingSchema,
         params={
-            "page": {"limit": -1,},
-            "fields[locus_listing]": "locus",
+            "sort": "-properties.newest_alert_observation_time",
             "elasticsearch_query[locus_listing]": json.dumps(query),
         },
     )
 
 
 def cone_search(
-    center: astropy.coordinates.SkyCoord, radius: astropy.coordinates.Angle
+    center: astropy.coordinates.SkyCoord,
+    radius: astropy.coordinates.Angle,
 ) -> Iterator[Locus]:
+    """
+    Searches the ANTARES database for loci in a certain region. Results are returned
+    with the most recently updated objects first (sorted on the
+    `properties.newest_alert_observation_time` field in descending order).
+
+    Parameters
+    ----------
+    center: astropy.coordiantes.SkyCoord
+    radius: astropy.coordiantes.Angle
+
+    Returns
+    ----------
+    Iterator over Locus objects
+
+    """
     return search(
         {
             "query": {
@@ -46,7 +66,7 @@ def cone_search(
                     "filter": {
                         "sky_distance": {
                             "distance": f"{radius.to_string(unit=astropy.units.deg, decimal=True)} degree",
-                            "htm16": {"center": center.to_string(),},
+                            "htm16": {"center": center.to_string()},
                         },
                     },
                 },
@@ -55,14 +75,38 @@ def cone_search(
     )
 
 
-def get_by_id(locus_id) -> Optional[Locus]:
-    return get_resource(
+def get_by_id(locus_id: str) -> Optional[Locus]:
+    """
+    Gets an ANTARES locus by its ANTARES ID.
+
+    Parameters
+    ----------
+    locus_id: str
+
+    Returns
+    ----------
+    Locus or None
+
+    """
+    return _get_resource(
         urljoin(config["ANTARES_API_BASE_URL"], "loci/{}".format(locus_id)),
-        LocusSchema,
+        _LocusSchema,
     )
 
 
-def get_by_ztf_object_id(ztf_object_id) -> Optional[Locus]:
+def get_by_ztf_object_id(ztf_object_id: str) -> Optional[Locus]:
+    """
+    Gets an ANTARES locus by its ZTF Object ID.
+
+    Parameters
+    ----------
+    ztf_object_id: str
+
+    Returns
+    ----------
+    Locus or None
+
+    """
     try:
         return next(
             search(
@@ -70,7 +114,7 @@ def get_by_ztf_object_id(ztf_object_id) -> Optional[Locus]:
                     "query": {
                         "bool": {
                             "filter": {
-                                "term": {"properties.ztf_object_id": ztf_object_id,},
+                                "term": {"properties.ztf_object_id": ztf_object_id},
                             },
                         },
                     },
